/**
 * Copyright (c) 2012 Nokia Corporation.
 */

import QtQuick 1.1
import com.nokia.meego 1.0
import CustomElements 1.0

Item {
    id: main

    function resetView() {
        cameraView.resetView();
    }

    property real controlOpacity: 0.7

    anchors.fill: parent

    Component.onCompleted: {
        main.state = "CameraView";
        cameraView.start();
    }

    CustomCamera {
        id: camera

        anchors.fill: parent

        imageAnalyzer: cameraView.imageAnalyzer

        onLockFailed: { cameraView.indicateLockStatus("failed"); }
        onLocked: { cameraView.indicateLockStatus("locked"); }

        onImageSaved: {
            cameraView.lastCapturedImage = fileName;
            Qt.openUrlExternally("file:///" + cameraView.lastCapturedImage);
        }
    }

    CameraView {
        id: cameraView

        anchors.fill: parent

        // Pass the CustomCamera object for easier access.
        camera: camera

        controlOpacity: main.controlOpacity
        onSettingsPressed: { main.state = "SettingsView"; }
        onRequestCameraView: { main.state = "CameraView"; }
    }

    SettingsView {
        id: settingsView

        anchors.fill: parent

        // Pass the CustomCamera object for easier access.
        camera: camera

        opacity: 0
        controlOpacity: main.controlOpacity

        onBackPressed: { main.state = "CameraView"; }
        onInfoPressed: { main.state = "InfoView"; }
    }

    InfoView {
        id: infoView

        anchors.fill: parent

        opacity: 0
        controlOpacity: main.controlOpacity
        onBackPressed: { main.state = "SettingsView"; }
    }

    states: [
        State {
            name: "CameraView"

            PropertyChanges { target: settingsView; opacity: 0 }
            PropertyChanges { target: cameraView; opacity: 1 }
            PropertyChanges { target: infoView; opacity: 0 }
        },
        State {
            name: "SettingsView"

            PropertyChanges { target: cameraView; opacity: 0 }
            PropertyChanges { target: settingsView; opacity: 1 }
            PropertyChanges { target: infoView; opacity: 0 }
        },
        State {
            name: "InfoView"

            PropertyChanges { target: cameraView; opacity: 0 }
            PropertyChanges { target: settingsView; opacity: 0 }
            PropertyChanges { target: infoView; opacity: 1 }
        }
    ]

    transitions: [
        Transition {
            PropertyAnimation {
                property: "opacity"
                duration: 200
            }
        }
    ]
}
