/**
 * Copyright (c) 2012 Nokia Corporation.
 */

import QtQuick 1.1
import com.nokia.symbian 1.1
import CustomElements 1.0

Item {
    id: settingsView

    property CustomCamera camera

    property real labelWidth: 160
    property real sliderWidth: 400
    property real controlOpacity

    signal backPressed()
    signal infoPressed()

    Rectangle {
        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom
        }

        width: 170

        color: "black"
        opacity: 0.7
    }

    Flickable {
        anchors {
            top: parent.top; topMargin: 45
            bottom: backButton.top; bottomMargin: 10
            left: parent.left; leftMargin: 20
            right: parent.right; rightMargin: 10
        }

        contentWidth: width
        contentHeight: settingsColumn.height

        Column {
            id: settingsColumn

            spacing: 5

            Row {
                Label {
                    width: settingsView.labelWidth
                    height: contrastSlider.height
                    opacity: settingsView.controlOpacity

                    text: "Contrast"
                    verticalAlignment: Text.AlignVCenter
                }

                Slider {
                    id: contrastSlider

                    width: settingsView.sliderWidth
                    opacity: settingsView.controlOpacity

                    valueIndicatorVisible: true
                    valueIndicatorText: value.toFixed(0)

                    minimumValue: -100
                    maximumValue: 100
                    value: settingsView.camera.contrast
                    onValueChanged: { camera.contrast = value; }
                }
            }

            Row {
                Label {
                    width: settingsView.labelWidth
                    height: sharpeningSlider.height
                    opacity: settingsView.controlOpacity

                    text: "Sharpening"
                    verticalAlignment: Text.AlignVCenter
                }

                Slider {
                    id: sharpeningSlider

                    width: settingsView.sliderWidth
                    opacity: settingsView.controlOpacity

                    valueIndicatorVisible: true
                    valueIndicatorText: value.toFixed(0)

                    minimumValue: 0
                    maximumValue: 100
                    value: settingsView.camera.sharpeningLevel
                    onValueChanged: { camera.sharpeningLevel = value; }
                }
            }

            Item { width: 10; height: 5 }

            Row {
                spacing: 20

                Label {
                    width: settingsView.labelWidth
                    height: whiteBalanceAutoButton.height
                    opacity: settingsView.controlOpacity

                    text: "White balance"
                    verticalAlignment: Text.AlignVCenter
                }

                ButtonRow {

                    Button {
                        id: whiteBalanceAutoButton

                        width: 180

                        opacity: settingsView.controlOpacity
                        iconSource: "../images/wb_auto.svg"

                        onClicked: {
                            camera.whiteBalanceMode =
                                    CustomCamera.WhiteBalanceAuto;
                        }
                    }

                    Button {
                        id: whiteBalanceCloudyButton

                        opacity: settingsView.controlOpacity
                        iconSource: "../images/wb_cloudy.svg"

                        onClicked: {
                            camera.whiteBalanceMode =
                                    CustomCamera.WhiteBalanceCloudy;
                        }
                    }

                    Button {
                        id: whiteBalanceFluorescentButton

                        opacity: settingsView.controlOpacity
                        iconSource: "../images/wb_fluorescent.svg"

                        onClicked: {
                            camera.whiteBalanceMode =
                                    CustomCamera.WhiteBalanceFluorescent;
                        }
                    }

                    Button {
                        id: whiteBalanceSunlightButton

                        opacity: settingsView.controlOpacity
                        iconSource: "../images/wb_sunlight.svg"

                        onClicked: {
                            camera.whiteBalanceMode =
                                    CustomCamera.WhiteBalanceSunlight;
                        }
                    }

                    Button {
                        id: whiteBalanceTungstenButton

                        opacity: settingsView.controlOpacity
                        iconSource: "../images/wb_tungsten.svg"

                        onClicked: {
                            camera.whiteBalanceMode =
                                    CustomCamera.WhiteBalanceTungsten;
                        }
                    }
                }
            }

            Item { width: 10; height: 5 }

            Row {
                spacing: 20

                Label {
                    width: settingsView.labelWidth
                    height: exposureAutoButton.height
                    opacity: settingsView.controlOpacity

                    text: "Exposure modes"
                    verticalAlignment: Text.AlignVCenter
                }

                ButtonRow {

                    Button {
                        id: exposureAutoButton

                        width: 150
                        opacity: settingsView.controlOpacity
                        iconSource: "../images/exposure_auto.svg"

                        onClicked: {
                            camera.exposureMode = CustomCamera.ExposureAuto;
                        }
                    }

                    Button {
                        id: exposureBackLightButton

                        opacity: settingsView.controlOpacity
                        iconSource: "../images/exposure_backlight.svg"

                        onClicked: {
                            camera.exposureMode =
                                    CustomCamera.ExposureBacklight;
                        }
                    }

                    Button {
                        id: exposureNightButton

                        opacity: settingsView.controlOpacity
                        iconSource: "../images/exposure_night.svg"

                        onClicked: {
                            camera.exposureMode = CustomCamera.ExposureNight;
                        }
                    }

                    Button {
                        id: exposureSportsButton

                        opacity: settingsView.controlOpacity
                        iconSource: "../images/exposure_sport.svg"

                        onClicked: {
                            camera.exposureMode = CustomCamera.ExposureSports;
                        }
                    }
                }
            }
        }
    }

    ToolButton {
        id: backButton

        anchors {
            left: parent.left; leftMargin: 10
            bottom: parent.bottom; bottomMargin: 10
        }

        opacity: settingsView.controlOpacity
        iconSource: "toolbar-back"

        onClicked: { settingsView.backPressed(); }
    }

    Button {
        id: infoViewButton

        anchors {
            right: parent.right; rightMargin: 10
            bottom: parent.bottom; bottomMargin: 10
        }

        opacity: settingsView.controlOpacity
        text: "i"

        onClicked: { settingsView.infoPressed(); }
    }
}
